@@ -29,6 +29,9 @@ description:
     - Manages NetStream template configuration on HUAWEI CloudEngine switches.
 author:
     - wangdezhuang (@QijunPan)
+notes:
+    - Recommended connection is C(network_cli).
+    - This module also works with C(local) connections for legacy playbooks.
 options:
     state:
         description:
